@@ -48,6 +48,7 @@
 # include <gpgme++/interfaces/progressprovider.h>
 #endif
 
+#include "job.h"
 
 #include <cassert>
 
@@ -147,14 +148,20 @@ protected:
     explicit ThreadedJobMixin(GpgME::Context *ctx)
         : T_base(0), m_ctx(ctx), m_thread(), m_auditLog(), m_auditLogError()
     {
-
     }
 
     void lateInitialization()
     {
         assert(m_ctx);
-        QObject::connect(&m_thread, SIGNAL(finished()), this, SLOT(slotFinished()));
+        QObject::connect(&m_thread, &QThread::finished, this,
+                         &mixin_type::slotFinished);
         m_ctx->setProgressProvider(this);
+        QGpgME::g_context_map.insert(this, m_ctx.get());
+    }
+
+    ~ThreadedJobMixin()
+    {
+        QGpgME::g_context_map.remove(this);
     }
 
     template <typename T_binder>
