@@ -29,6 +29,10 @@
     your version.
 */
 
+#ifdef HAVE_CONFIG_H
+ #include "config.h"
+#endif
+
 #include <QDebug>
 #include <QTest>
 #include <QSignalSpy>
